@@ -140,7 +140,7 @@ class File(models.Model):
     class Meta:
         verbose_name = 'file'
         verbose_name_plural = 'files'
-        ordering = ['file_type__source', '-file_type__compression', 'state', 'year', 'filename']
+        ordering = ['file_type__source', 'state__abbreviation', 'year', 'file_type__compression', 'filename']
     
     
     def get_absolute_url(self):
