@@ -205,7 +205,6 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
         dsabbr = destination.source.abbreviation
         
         # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
-        
         if ('psycopg2' in DB_BACKEND and (
                 ((dsabbr.upper() in ['CORE', 'BASE']) or
                  (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
@@ -220,10 +219,11 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
         else:
             logger.info('Sending to chunk_import_file: %s' % (load))
             chunk_import_file.delay(load.pk)
+            return True
 
 
 @celery.shared_task(bind=True, ignore_result=True)
-def pg_import_file(self, importqueue_pk, drop_intermediate_tables=False):# change to True for production
+def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     """Assumes psycopg2 availability.
     """
     
@@ -273,23 +273,33 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=False):# chang
     # let 'er rip
     meta = load.get_meta()
     
+    logger.info('Creating raw import table via pg_rawload(): %s' % (load))
     rawload = pg_rawload(cnxn, handle, meta)
+    logger.info('Raw import table %s populated: %s' % (rawload, load))
     
     if load.file.file_type.source.abbreviation in pyhcup.parser.LONG_MAPS.keys():
         pk_fields = None
+        logger.info('Staging will be done with no primary key: %s' % (load))
     else:
         pk_fields = ['key', 'state', 'year']
+        logger.info('Staging will be done with primary key %s: %s' % (pk_fields, load))
     
+    logger.info('Creating staging table via pg_staging(): %s' % (load))
     staging = pg_staging(cnxn, rawload, meta, state, year, pk_fields=pk_fields)
+    logger.info('Staging table %s populated: %s' % (staging[0], load))
     
     fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
     fields += ['state', 'year']
     
+    logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
     affected_rows = pg_shovel(cnxn, staging[0], table, fields)
+    logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
     
     if drop_intermediate_tables:
-        pg_drop(cnxn, rawload)
-        pg_drop(cnxn, staging[0])
+        drop_targets = [rawload, staging[0]]
+        logger.info('Dropping intermediate tables %s as part of load for %s' % (drop_targets, load))
+        for dtbl in drop_targets:
+            pg_drop(cnxn, dtbl)
     
     # affected_rows will evaluate un-True in the case of any troubles
     if affected_rows:
@@ -370,6 +380,41 @@ def chunk_import_file(self, importqueue_pk, insert_size=5, slice_size=1000):
                 )
             )
     
+    # take 6
+    # slices chained, chunker.chunks() for each
+    # this is preferred to another chunker here as all files chunking simultaneously
+    # tends to hang for a while
+    """
+    result_lst = [
+        # ...
+        for df in reader
+    ]
+    for df in reader:
+        # everything we insert will always have a state and year associated with it
+        # if they aren't already in the frame, add them from the passed values
+        # (which should in turn be from the loadfile object)
+        if 'state' not in df.columns.map(lambda x: str(x).lower()):
+            df['state'] = state
+        
+        if 'year' not in df.columns.map(lambda x: str(x).lower()):
+            df['year'] = year
+        
+        cleaned_df = replace_sentinels(df)
+        
+        if dsabbr == 'CHGS' and not meta_is_long(meta):
+            # this is a wide charges file
+            # convert before chunking it out
+            cleaned_df = df_wtl(cleaned_df, category='CHGS')
+        
+        result_lst.append(chunker(
+                cleaned_df,
+                table,
+                schema,
+                insert_size
+                )
+            )
+    """
+    
     import_complete.apply_async((result_lst, load.pk), countdown=10)
     return True
 
